/*
 * validatefqdn.c -- part of leafnode.
 *
 * Copyright (C) 2002 Matthias Andree <matthias.andree@gmx.de>.
 * All rights reserved.
 *

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are
   met:

     * Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions and the following disclaimer in the
       documentation and/or other materials provided with the distribution.
     * Neither the name of Matthias Andree nor the names of its
       contributors may be used to endorse or promote products derived from
       this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
   IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
   THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
   PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
*/

/* This function checks that the hostname contains at least a dot, does
 * not start with localhost and does not start with 127.0.0. -- if it
 * does, syslog, print to stderr and die.
 */

#include <stdlib.h>
#include <string.h>
#include "leafnode.h"

void
validatefqdn(int logtostdout)
{
    /* kill bogus fqdn */
    if (!strchr(fqdn, '.')
	|| !strncasecmp(fqdn, "localhost", 9)
	|| !strncmp(fqdn, "127.0.0.", 8)
	) {
	const char *const fmt =
	    "\nLeafnode must have a fully-qualified domain name,\n"
	    "not just \"%s\".\nEdit your /etc/hosts file to add "
	    "a fully qualified domain name.\n\n";
	if (logtostdout) {
		printf("503 Leafnode must have a fully-qualified domain name. Have its administrator fix the configuration. More detail is in the logs.\r\n");
	}
	syslog(LOG_CRIT, fmt, fqdn);	/* Flawfinder: ignore */
	fprintf(stderr, fmt, fqdn);	/* Flawfinder: ignore */
	abort();
	exit(127);
    }
}
